==> HostCMS.Free_6.7.tar.gz: modules/company/i18n/en.php <==
<?php
/**
 * Companies
 *
 * @package HostCMS
 * @subpackage Company
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2017 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Companies',
	'company_show_title2' => 'Companies',
	'company_show_title' => 'Company',
	'company_show_title_add' => 'Add',
	'company_form_add_title' => 'Add company information',
	'company_form_edit_title' => 'Edit company information',
	'name' => '<acronym title="Company name">Name</acronym>',
	'description' => '<acronym title="Company description">Description</acronym>',
	'tin' => '<acronym title="Company Taxpayer ID">Taxpayer ID</acronym>',
	'kpp' => '<acronym title="Record validity code of company">RVC</acronym>',
	'psrn' => '<acronym title="Primary state registration number of company">PSRN</acronym>',
	'okpo' => '<acronym title="All-Russia Classifier of Enterprises and Organizations number of company">ARCEO</acronym>',
	'okved' => '<acronym title="All-Russia Classifier of Economic Activities number of company">ARCEA</acronym>',
	'bic' => '<acronym title="Russian Central Bank Identification Code of company">RCBIC</acronym>',
	'current_account' => '<acronym title="Account number of company">Account number</acronym>',
	'correspondent_account' => '<acronym title="Correspondent account number of company">Correspondent account number</acronym>',
	'bank_name' => '<acronym title="Bank name">Bank name</acronym>',
	'bank_address' => '<acronym title="Bank address">Bank address</acronym>',
	'legal_name' => '<acronym title="Full name of director of company">Full name of director</acronym>',
	'accountant_legal_name' => '<acronym title="Full name of general account of company">Full name of general accountant</acronym>',
	'address' => '<acronym title="Company address">Address</acronym>',
	'phone' => '<acronym title="Company phone">Phone</acronym>',
	'fax' => '<acronym title="Company fax">Fax</acronym>',
	'site' => '<acronym title="Company website">Website</acronym>',
	'email' => '<acronym title="Company e-Mail">E-Mail</acronym>',
	'tabManagers' => 'Guidelines',
	'tabContacts' => 'Contact details',
	'tabBankingDetails' => 'Account details',
	'guid' => 'GUID',
	'edit_success' => 'Company information updated successfully.',
	'edit_error' => 'Error while adding company information!',
	'markDeleted_success' => "Company information deleted successfully",
	'id' => "Id",
	'company_shop_title' => 'Companies',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'sites' => 'Sites',
	'show_sds_link' => 'References',
	'show_posts' => 'Company posts',
	'show_email_types' => 'Email types',
	'show_phone_types' => 'Phone types',
	'show_address_types' => 'Address types',	
	'show_socials' => 'Socials',
	'show_messengers' => 'Messengers'
);

==> HostCMS.Free_7.0.tar.gz: modules/company/i18n/en.php <==
<?php
/**
 * Companies
 *
 * @package HostCMS
 * @subpackage Company
 * @version 7.x
 * @author Hostmake LLC
 * @copyright © 2005-2023 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Companies',
	'company_show_title2' => 'Companies',
	'company_show_title' => 'Company',
	'company_show_title_add' => 'Add',
	'company_form_add_title' => 'Add company information',
	'company_form_edit_title' => 'Edit company information',
	'name' => 'Name',
	'description' => 'Description',
	'tin' => 'Taxpayer ID',
	'kpp' => '<acronym title="Record validity code of company">RVC</acronym>',
	'psrn' => '<acronym title="Primary state registration number of company">PSRN</acronym>',
	'okpo' => '<acronym title="All-Russia Classifier of Enterprises and Organizations number of company">ARCEO</acronym>',
	'okved' => '<acronym title="All-Russia Classifier of Economic Activities number of company">ARCEA</acronym>',
	'legal_name' => 'Full name of director',
	'accountant_legal_name' => 'Full name of general accountant',
	'address' => 'Address',
	'phone' => 'Phone',
	'fax' => 'Fax',
	'site' => 'Website',
	'email' => 'E-Mail',
	'tabManagers' => 'Guidelines',
	'tabContacts' => 'Contact details',
	'tabBankingDetails' => 'Details',
	'guid' => 'GUID',
	'edit_success' => 'Company information updated successfully.',
	'edit_error' => 'Error while adding company information!',
	'markDeleted_success' => "Company information deleted successfully",
	'id' => "Id",
	'company_shop_title' => 'Companies',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'sites' => 'Sites',
	'show_sds_link' => 'References',
	'show_posts' => 'Company posts',
	'show_email_types' => 'Email types',
	'show_phone_types' => 'Phone types',
	'show_address_types' => 'Address types',
	'show_socials' => 'Socials',
	'show_messengers' => 'Messengers',
	'sorting' => 'Sorting',
	'apply_success' =>	'Item changed successfully!',
	'image' => 'Image',
	'tin_list' => 'TIN: %s',
);
